# Generated by Django 3.0.8 on 2020-07-02 16:08

from django.db import migrations, models

import django_q.models


class Migration(migrations.Migration):
    dependencies = [
        ("django_q", "0011_auto_20200628_1055"),
    ]

    operations = [
        migrations.AlterField(
            model_name="schedule",
            name="cron",
            field=models.CharField(
                blank=True,
                help_text="Cron expression",
                max_length=100,
                null=True,
                validators=[django_q.models.validate_cron],
            ),
        ),
    ]
